<?php
/*
 * Passport Featured Posts By Post Format Widget
 * -------------------------------------------------------------------------
 *
 * @package WordPress
 * @subpackage passport
 * @since passport 1.0
 *
 */
class Passport_Featured_Posts_By_Post_Format_Widget extends WP_Widget {

function __construct() {
	$widget_ops = array( 'classname' => 'widget_featured_posts_by_post_format clearfix', 'description' => esc_html__( 'Display posts of specific post format', 'passport' ) );
	parent::__construct( 'passport_featured_posts_by_post_format_Widget', esc_html__( 'Passport Featured Posts by Post Format', 'passport' ), $widget_ops );

    $this->alt_option_name = 'widget_featured_posts_by_post_format';
    add_action( 'wp_enqueue_scripts', array( $this, 'passport_widget_inline_style' ) );

}


/**
 * Styling the widget
 */
public function passport_widget_inline_style() { 
    $i = 0;

    $widget_options = get_option( $this->option_name );

    $custom_widget_css = '';
        if( is_array( $widget_options ) && count( $widget_options ) > 0 ) {
			foreach ( $widget_options as $key => $widget_option ) {
     
                $widget_title_bgcolor_option = isset( $widget_option['widget_title_bgcolor'] ) ? $widget_option['widget_title_bgcolor'] : '';
 
                if ( isset( $widget_title_bgcolor_option ) ) {
                    $custom_widget_css .= "#{$this->id_base}-{$key} .widget-title {";
                    $custom_widget_css .= ! empty( $widget_title_bgcolor_option ) ? 'background-color:'. $widget_title_bgcolor_option .';' :'background-color: #333333;';
                    $custom_widget_css .= "}";
                    $custom_widget_css .= "#{$this->id_base}-{$key} .widget-title span {";
                    $custom_widget_css .= 'color: #ffffff;';
                    $custom_widget_css .= "}";
    	       }
            $i++;
	    }
    }
    wp_add_inline_style( PASSPORT_THEME_SLUG . '-custom-style', $custom_widget_css );   
}


// Creating widget front-end
public function widget( $args, $instance ) {

	global $post;
	global $passport_number;
	
	$title				= ! empty( $instance['title'] ) ? $instance['title'] : '';
	$post_format		= ! empty( $instance['post_format'] ) ? $instance['post_format'] : 'post-format-image';
	$image_position		= ! empty( $instance['image_position'] ) ? $instance['image_position'] : 'left' ;
	$exclude			= ! empty( $instance['exclude'] ) ? $instance['exclude'] : '';
	$excludeArry		= explode( ',', $exclude );
	$orderby			= ! empty( $instance['orderby'] ) ?  $instance['orderby'] : 'date';
	$order				= ! empty( $instance['order'] ) ? $instance['order'] : 'desc';
	$widget_icon		= ! empty( $instance['widget_icon'] ) ? $instance['widget_icon'] : '';
	$frontpage_id		= get_option( 'page_on_front' );
	$attachment_id		= get_post_thumbnail_id( $frontpage_id );

	$widget_args			= array(
		'post_type'			=> 'post',
		'posts_per_page'	=> 3,
		'order'				=> $order,
		'orderby'			=> $orderby,
		'post__not_in'		=> $excludeArry,
		'tax_query' => array(
		array(
			'taxonomy'		=> 'post_format',
			'field'			=> 'slug',
			'terms'			=> $post_format,
			)
		)
	);

	$wp_query	= new WP_Query( $widget_args );
?>
	<?php echo $args['before_widget']; ?>
	<?php if ( ! empty( $title ) ) {  echo '<h4 class="widget-title"><i class="'. $widget_icon .'"></i> <span>'. $title .'</span></h4>'; } ?>
		<div class="widget-container">
			<div class="col-xs-12 col-sm-12 col-md-8 col-lg-8 <?php if ( 'right' == $image_position ) { echo 'alignright'; } ?>">
				<div class="row">
					<div class="widget-post-item clearfix">
						<?php if ( $wp_query->have_posts() ) : ?>
							<?php while ( $wp_query->have_posts() ) : $wp_query->the_post(); ?>
								<?php if ( $wp_query->current_post == 0 ) : ?>
									<?php	
										$format = get_post_format();
										get_template_part( 'partials/format', $format );  
									?>
								<?php endif; ?>
							<?php endwhile; ?>
						<?php endif; ?>
					</div>
				</div>
			</div>
			<div class="col-xs-12 col-sm-12 col-md-4 col-lg-4">
				<div class="row">
					<?php if ( $wp_query->have_posts() ) : ?>
                    <ul class="list-unstyled">
						<?php while ( $wp_query->have_posts() ) : $wp_query->the_post(); ?>
							<?php if ( $wp_query->current_post >= 1 ) : 
							    $post_format    = get_post_format( get_the_ID() );
                                $aside_active   = get_post_meta( get_the_ID(), 'as_active', true );
                                $audio_active	= get_post_meta( get_the_ID(), 'a_active', true );
                                $gallery_active	= get_post_meta( get_the_ID(), 'g_active', true );
                                $image_active	= get_post_meta( get_the_ID(), 'i_active', true );
                                $link_active	= get_post_meta( get_the_ID(), 'l_active', true );
                                $quote_active	= get_post_meta( get_the_ID(), 'q_active', true );
                                $video_active	= get_post_meta( get_the_ID(), 'v_active', true);
                                $gallery_type	= get_post_meta( get_the_ID(), 'g_type', true );

                     	        $archive_year		= get_the_time( 'Y' ); 
								$archive_month		= get_the_time( 'm' ); 
								$archive_day		= get_the_time( 'd' );
                            ?>
                            <li class="widget-post-item clearfix">
						        <div class="<?php if( has_post_thumbnail() || 0 != $attachment_id ) { echo 'has-thumbnail'; } else { echo 'no-thumbnail'; } ?>">
							        <article id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
                                        <div class="post-media">
                                            <?php   
                                                if( false == $post_format ) {
                                                    get_template_part( 'partials/partials', 'image' );
                                                } elseif( 'aside' == $post_format && ! empty( $aside_active ) ) {
                                                    echo passport_display_aside_post_format();
                                                } elseif( 'link' == $post_format && ! empty( $link_active ) ) {
                                                    echo passport_display_link_post_format();
                                                } elseif( 'quote' == $post_format && ! empty( $quote_active ) ) {
	                                                echo passport_display_quote_post_format();
                                                } elseif( 'image' == $post_format && ! empty( $image_active ) ) {
	                                                echo passport_display_image_post_format();
                                                } elseif( 'gallery' == $post_format && ! empty( $gallery_active ) ) {
                                                    echo passport_display_gallery_post_format();
                                                } elseif( 'audio' == $post_format && ! empty( $audio_active ) ) {
		                                            echo passport_display_audio_post_format();
                                                } elseif( 'video' == $post_format && ! empty( $video_active ) ) {
	                                                echo passport_display_video_post_format();
                                                } else {
                                                    get_template_part( 'partials/partials', 'image' );        
                                                }
                                            ?>
            					        </div>		  
                                        <div class="post-content">
								            <h4 class="entry-title"><a href="<?php the_permalink(); ?>"><?php echo passport_short_title( get_the_title(), 45 ); ?></a></h4>
                                            <a href="<?php echo esc_url( get_day_link( $archive_year, $archive_month, $archive_day ) ); ?>">
                                                <span class="post-info clearfix"><?php echo get_the_date( 'M j, Y' ); ?></span>
                                            </a>
								        </div>
							        </article>
						        </div>
                            </li>
							<?php endif; ?>
						<?php endwhile; ?>
                        </ul>
					<?php endif; ?>
				</div>
			</div>
		</div>
	<?php  wp_reset_postdata(); ?>
	<?php echo $args['after_widget']; ?>
<?php }
		

// Widget Backend 
public function form( $instance ) {
	
//Set up some default widget settings.
		$instance			= wp_parse_args( (array) $instance, array(  
			'title'				   => '', 
			'post_format'		   => 'post-format-image', 
			'image_position'	   => 'left', 
			'orderby'			   => 'date', 
			'order'				   => 'desc', 
			'exclude'			   => '', 
			'widget_icon'		   => '', 
			'widget_title_bgcolor' => '#333333' 
		) );
		$title				  = $instance['title'];
		$exclude			  = $instance['exclude'];
		$widget_icon		  = $instance['widget_icon'];
		$widget_title_bgcolor = $instance['widget_title_bgcolor'];

// Widget admin form
?>
	<p>
		<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php esc_html_e( 'Widget Title:', 'passport' ); ?></label>
		<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
	</p>

	<p>
		<label for="<?php echo $this->get_field_id( 'post_format' ); ?>"><?php esc_html_e( 'Post Format:', 'passport' ); ?></label>
		<select name="<?php echo $this->get_field_name( 'post_format' ); ?>" id="<?php echo $this->get_field_id( 'post_format' ); ?>">
			<?php $post_formats = array( 'aside', 'link', 'quote', 'image', 'gallery', 'audio', 'video' ); ?>
			<?php foreach( $post_formats as $post_format ) : $term_name = 'post-format-'. $post_format .''; ?>
				<option value="<?php echo $term_name; ?>"<?php selected( $instance['post_format'], $term_name ); ?>><?php echo $term_name; ?></option>
			<?php endforeach; ?>
		</select>
	</p>

	<p>
		<label for="<?php echo $this->get_field_id( 'image_position' ); ?>"><?php esc_html_e( 'Main Post Position:', 'passport' ); ?></label>
		<select name="<?php echo $this->get_field_name( 'image_position' ); ?>" id="<?php echo $this->get_field_id( 'image_position' ); ?>">
			<option value="left"<?php selected( $instance['image_position'], 'left' ); ?>><?php esc_html_e( 'Left', 'passport' ); ?></option>
			<option value="right"<?php selected( $instance['image_position'], 'right' ); ?>><?php esc_html_e( 'Right', 'passport' ); ?></option>
		</select>
	</p>

	<p>
		<label for="<?php echo $this->get_field_id( 'exclude' ); ?>"><?php esc_html_e( 'Exclude:', 'passport' ); ?></label> 
        <input type="text" value="<?php echo esc_attr( $exclude ); ?>" name="<?php echo $this->get_field_name( 'exclude' ); ?>" id="<?php echo $this->get_field_id( 'exclude' ); ?>" size="35"/>
		<br />
		<small><?php esc_html_e( 'Post IDs, separated by commas.', 'passport' ); ?></small>
	</p>

	<p>
		<label for="<?php echo $this->get_field_id( 'orderby' ); ?>"><?php esc_html_e( 'Order by:', 'passport' ); ?></label>
		<select name="<?php echo $this->get_field_name( 'orderby' ); ?>" id="<?php echo $this->get_field_id( 'orderby', 'passport' ); ?>">
			<option value="none"<?php selected( $instance['orderby'], 'none' ); ?>><?php esc_html_e( 'None', 'passport' ); ?></option>
            <option value="date"<?php selected( $instance['orderby'], 'date' ); ?>><?php esc_html_e( 'Date', 'passport' ); ?></option>
            <option value="author"<?php selected( $instance['orderby'], 'author' ); ?>><?php esc_html_e( 'Author', 'passport' ); ?></option>
            <option value="title"<?php selected( $instance['orderby'], 'title' ); ?>><?php esc_html_e( 'Title', 'passport' ); ?></option>
            <option value="name"<?php selected( $instance['orderby'], 'name' ); ?>><?php esc_html_e( 'Name', 'passport' ); ?></option>
            <option value="type"<?php selected( $instance['orderby'], 'type' ); ?>><?php esc_html_e( 'Type', 'passport' ); ?></option>
            <option value="modified"<?php selected( $instance['orderby'], 'modified' ); ?>><?php esc_html_e( 'Modified', 'passport' ); ?></option>
            <option value="rand"<?php selected( $instance['orderby'], 'rand' ); ?>><?php esc_html_e( 'Rand', 'passport' ); ?></option>
		</select>
	</p>

	<p>
		<label for="<?php echo $this->get_field_id( 'order' ); ?>"><?php esc_html_e( 'Order:', 'passport' ); ?></label>
		<select name="<?php echo $this->get_field_name( 'order' ); ?>" id="<?php echo $this->get_field_id( 'order' ); ?>">
			<option value="desc"<?php selected( $instance['order'], 'desc' ); ?>><?php esc_html_e( 'DESC', 'passport' ); ?></option>
			<option value="asc"<?php selected( $instance['order'], 'asc' ); ?>><?php esc_html_e( 'ASC', 'passport' ); ?></option>
		</select>
	</p>

	<h4><?php esc_html_e( 'Widget Style', 'passport' ); ?></h4>
	<p>
		<label for="<?php echo $this->get_field_id( 'widget_icon' ); ?>"><?php esc_html_e( 'Icon:', 'passport' ); ?></label>
		<input class="widefat" id="<?php echo $this->get_field_id( 'widget_icon' ); ?>" name="<?php echo $this->get_field_name( 'widget_icon' ); ?>" type="text" value="<?php echo esc_attr( $widget_icon ); ?>" />
		<br />
		<small><?php esc_html_e( 'Please choose your  fontawesome icon. For example: fa fa-home.', 'passport' ); ?></small>
		<small><a href="<?php echo esc_url( 'https://fortawesome.github.io/Font-Awesome/cheatsheet/' ); ?>" target="_blank"><b><?php esc_html_e( 'Find your icon:', 'passport' ); ?></b></a></small>
	</p>

	<label for="<?php echo $this->get_field_id( 'widget_title_bgcolor' ); ?>" style="display:block;"><?php esc_html_e( 'Widget Title Background Color:', 'passport' ); ?></label><br />
	<input class="widefat color" id="<?php echo $this->get_field_id( 'widget_title_bgcolor' ); ?>" name="<?php echo $this->get_field_name( 'widget_title_bgcolor' ); ?>" type="text" value="<?php echo esc_attr( $widget_title_bgcolor ); ?>" />
	<div class="colorpicker"></div>

<?php }
	
// Updating widget replacing old instances with new instances
public function update( $new_instance, $old_instance ) {
	
	$instance = $old_instance;

	//Define Array

	$post_formats		  = array( 'aside', 'link', 'quote', 'image', 'gallery', 'audio', 'video' );
	foreach( $post_formats as $post_format ) {
		$term_name		= 'post-format-'. $post_format .'';
		$term_names[]	= '' . $term_name . '';
	}
	$image_position_array = array( 'left', 'right' );
	$orderbyArry		  = array( 'none', 'date', 'author', 'title', 'name', 'parent', 'type', 'modified', 'rand' );
	$orderArry			  = array( 'desc', 'asc' );

	//Update new instances
	$instance['title']					= wp_filter_nohtml_kses( $new_instance['title']);
	if ( in_array( $new_instance['post_format'], $term_names ) ) {
			$instance['post_format']	= $new_instance['post_format'];
	} else {
			$instance['post_format']	= 'post-format-image';
	}
	if ( in_array( $new_instance['image_position'], $image_position_array ) ) {
		$instance['image_position']		= $new_instance['image_position'];
	} else {
		$instance['image_position']		= 'left';
	}
	$instance['exclude']				= wp_filter_nohtml_kses( $new_instance['exclude'] );	
	if ( in_array( $new_instance['orderby'], $orderbyArry ) ) {
		$instance['orderby']			= $new_instance['orderby'];
	} else {
		$instance['orderby']			= 'date';
	}
	if ( in_array( $new_instance['order'], $orderArry ) ) {
		$instance['order']				= $new_instance['order'];
	} else {
		$instance['order']				= 'desc';
	}
	$instance['widget_icon']			= wp_filter_nohtml_kses( $new_instance['widget_icon']);
	$instance['widget_title_bgcolor']	= wp_filter_nohtml_kses( $new_instance['widget_title_bgcolor']);

	return $instance;
	}

} // Class widget ends here

// Register and load the widget
function passport_featured_posts_by_post_format_load_widget() {
	register_widget( 'Passport_Featured_Posts_By_Post_Format_Widget' );
}
add_action( 'widgets_init', 'passport_featured_posts_by_post_format_load_widget' );